/* Generated file. */
#define AUTHORS \
"Author:\n"\
"Evan Battaglia <gtoevan@gmx.net>\n"\
"\n"\
"Contributors:\n"\
"Alex Foobarian <foobarian@gmail.com>\n"\
"Bernd Zeimetz <bernd@bzed.de>\n"\
"Guilhem Bonnefille <guilhem.bonnefille@gmail.com>\n"\
"Jocelyn Jaubert <jocelyn.jaubert@gmail.com>\n"\
"Mark Coulter <i_offroad@yahoo.com>\n"\
"Mathieu Albinet <mathieu17@gmail.com>\n"\
"Quy Tonthat <qtonthat@gmail.com>\n"\
"\n"\
"Few other bugfixes/minor patches from various contributors. See ChangeLog for details.\n"
